<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/svp?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'action_patienter' => 'اقدام‌هاي در دست انجام. لطفاً صبر كنيد...',
	'actions_a_faire' => 'اقدام‌هايي براي انجام دادن',
	'actions_demandees' => 'اقدام‌هاي درخواست شده:',
	'actions_en_erreur' => 'خطاهاي سرور',
	'actions_necessaires' => 'اقدام‌هاي تكميلي زير انچام خواهد شد: ',
	'actions_non_traitees' => 'اقدام‌هاي انجام نشده ',
	'actions_realises' => 'اقدام‌هاي انجام شده ',
	'afficher_les_plugins_incompatibles' => 'نمايش پلاگين‌هاي ناسازگار',

	// B
	'bouton_activer' => 'فعال سازي ',
	'bouton_actualiser' => 'عملي سازي',
	'bouton_actualiser_tout' => 'عملي سازي مخازن',
	'bouton_appliquer' => 'كاربرد',
	'bouton_confirmer' => 'تأييد',
	'bouton_desactiver' => 'غيرفعال‌سازي',
	'bouton_desinstaller' => 'نصب زدايي',
	'bouton_installer' => 'بارگذاري و فعال‌سازي ',
	'bouton_modifier_depot' => 'اصلاح مخزن',
	'bouton_supprimer' => 'حذف ',
	'bouton_up' => 'به هنگام سازي ',
	'bulle_actualiser_depot' => 'فعال سازي پاكت‌هاي مخزن',
	'bulle_actualiser_tout_depot' => 'فعال سازي پاكت‌هاي تمام مخزن‌ها',
	'bulle_afficher_xml_plugin' => 'مفاد پرونده‌ي ايكس.ام.ال پلاگين',
	'bulle_ajouter_spipzone' => 'افزودن مخزن SPIP-Zone',
	'bulle_aller_depot' => 'برو به صفحه‌ي اين مخزن

',
	'bulle_aller_documentation' => 'برو به صفحه‌ي مستندسازي ',
	'bulle_aller_plugin' => 'برو به صفحه‌ي پلاگين',
	'bulle_supprimer_depot' => 'حذف مخزن و پاكت‌هاي آن',
	'bulle_telecharger_archive' => 'بارگذاري آرشيو',
	'bulle_telecharger_fichier_depot' => 'بارگذاري پرونده ايكس.ام.ال مخزن',
	'bulle_telecharger_librairie' => 'بارگذاري آرشيو',

	// C
	'cacher_les_plugins_incompatibles' => 'پنهان ساختن پلاگين‌هاي ناسازگار ',
	'categorie_aucune' => 'بدون مقوله',
	'categorie_auteur' => 'تأييد، نويسنده، اختيار',
	'categorie_communication' => 'ارتباط، تعامل، پيك',
	'categorie_date' => 'يادداشت‌ها، تقويم، تاريخ',
	'categorie_divers' => 'چيزهاي نو، خدمات داخلي',
	'categorie_edition' => 'نشر، پرينت، نگارش',
	'categorie_maintenance' => 'پيكربندي، نگهداري',
	'categorie_multimedia' => 'تصويرها، گالري، چندرسانه',
	'categorie_navigation' => 'ناوبري، جستجو، سازماندهي',
	'categorie_outil' => 'ابزار توسعه',
	'categorie_performance' => 'بهينه سازي، عملكرد، امنيت',
	'categorie_squelette' => 'اسكلت',
	'categorie_statistique' => 'ارجاع، آمارها',
	'categorie_theme' => 'تم ',
	'config_activer_log_verbeux' => 'فعال‌سازي ثبت‌هاي طولاني؟',
	'config_activer_log_verbeux_explication' => 'اين گزينه‌ ثبت‌ اس.وي.پي را بسيار طولاني مي‌سازد...',
	'config_activer_pas_a_pas' => 'فعال سازي حالت گام به گام؟',
	'config_activer_pas_a_pas_explication' => 'فعال‌سازي اين حالت يك بيلان را بعد از هر اقدام انجام شده نشان خواهد داد، به جاي آنكه فقط يك بيلان كلي از تمام اقدام‌هاي انجام شده در پايان پروسه داشته باشيد.
',
	'config_activer_runtime' => 'فعال سازي حالت زمان اجرا؟ ',
	'config_activer_runtime_explication' => 'حالت زمان‌اجرا (بله) فقط پلاگين‌هاي غيرفعال سازگار با نسخه‌ي فعالي اسپيپ شما را بارگذاري مي‌كند، كه براي بيشتر استفاده‌ها به شدت توصيه مي‌شود. در حالت غير زمان اجرا (نه)، تمام پلاگين‌هاي يك مخزن بارگذاري مي‌شوند، بي‌توجه به اينكه نسخه‌ي اسپيپ چه باشد. اين حالت فقط هنگامي مفيد است كه اس.وي.پي براي ارايه‌ي تمام پلاگين‌هاي موجود مورد استفاده قرار بگيرد آنطور كه اسپيپ مي‌كند (plugins.spip.net) 
',
	'config_autoriser_activer_paquets_obsoletes' => 'اجازه‌ي فعال‌ سازي پاكت‌هاي كهنه؟',
	'config_autoriser_activer_paquets_obsoletes_explication' => 'پاكت‌هاي (بسته‌هاي) كهنه پاكت‌هاي محلي هستند كه قديمي‌تر از ساير پاكت‌هاي قديمي هستند. كهنگي بر مبناي وضعيت پاكت‌ها (استقرار، آزمون، توسعه) و بر مبناي نسخه تعيين مي‌شود. اگر هنوز مايليد اين پلاگين‌هاي تاريخ گذشته را فعال كنيد اين گزينه را توانا سازيد.  
',
	'config_depot_editable' => 'اجازه‌ي ويرايش سپرده‌ها؟',
	'config_depot_editable_explication' => 'اين اطلاعات ذخيره را ويرايش‌پذير مي‌سازد و همچنين به آن‌ها اجازه مي‌هد تا به كليد واژه‌ها يا سندها وصل شوند. اين گزينه نبايد مورد علاقه كسي باشد! بهتر است بگذاريد «نه» باشد!',
	'confirmer_telecharger_dans' => 'اين پلاگين در پوشه‌ي  (@dir@)كه فعلاً موجود است بارگذاري خواهد شد.
اين كار مطلب آن پوشه را از بين خواهد برد. 
يك كپي از مطلب قديمي در «@dir_backup@» ذخيره خواهد شد. 
		شما بايد اين عمل را تأييد كنيد. ',

	// E
	'erreur_actions_non_traitees' => 'بعضي از اقدام‌ها انجام نشده است. اين مي‌تواند ناشي از بروز خطا،حين پردازش آن اقدام‌ها، يا ناشي از نمايش اين صفحه هنگامي كه آن اقدام‌ها در دست پردازش بوده‌اند، باشد. اقدام‌ها به وسيله‌ي @auteur@در تاريخ @date@شروع شده‌اند. ',
	'erreur_dir_dib_ecriture' => 'پوشه‌ي آرشيو‌هاي @dir@ قابل نوشتن نيستب. بارگذاري يك آرشيو ممكن نيست.  ',
	'erreur_dir_dib_indefini' => 'پوشه‌ي  _DIR_LIB تعريف نشده. بارگذاري يك آرشيو ممكن نيست.',
	'erreur_dir_plugins_auto' => 'پوشه‌ي «plugins/auto»  كه اجازه‌ي بارگذاري پاكت‌ها را مي‌دهد ايجاد نشده يا در دسترس نوشتن نيست. 
		<strong>براي آنكه بتوانيد پلاگين‌هاي جديد را از طريق اين واسطه بارگذاري كنيد بايد آن پوشه را بسازيد.</strong>',
	'erreur_dir_plugins_auto_ecriture' => 'پوشه‌ي پاكت‌هاي  @dir@ قابل نوشتن نيست. بارگذاري يك پاكت مقدور نيست.',
	'erreur_dir_plugins_auto_indefini' => 'پوشيه‌ي _DIR_PLUGIN_AUTO تعريف نشده. جستجوي يك پاكت ممكن نيست. ',
	'erreur_dir_plugins_auto_titre' => '« plugins/auto »غيرقابل دسترس !',
	'erreur_teleporter_chargement_source_impossible' => 'بارگذاري اين منبع @source@ ممكن نيست',
	'erreur_teleporter_destination_erreur' => 'پوشه‌ي @dir@ براي انتقال دردسترس نيست',
	'erreur_teleporter_echec_deballage_archive' => 'خالي كردن  @fichier@ ممكن نيست',
	'erreur_teleporter_format_archive_non_supporte' => '   فرمت @extension@ توسط انتقال دهنده پشتيباني نمي‌شود',
	'erreur_teleporter_methode_inconue' => 'روش @methode@ براي انتقال ناشناخته است',
	'erreur_teleporter_type_fichier_inconnu' => 'نوع پرونده‌‌ي ناشناخته براي منبع @source@',
	'explication_destination' => 'اگر اين را پر نكنيد مسير با نام آرشيوي محاسبه خواهد شد. ',

	// F
	'fieldset_debug' => 'خطازدايي',
	'fieldset_edition' => 'ويرايش ',
	'fieldset_fonctionnement' => 'روش كار',

	// I
	'info_1_depot' => '1 مخزن',
	'info_1_paquet' => '1 پاكت (بسته)',
	'info_1_plugin' => '1 پلاگين',
	'info_admin_plugin_actif_non_verrou_non' => 'اين صفحه پلاگين‌هاي غيرفعال را فهرست مي‌كند. اين پلاگين‌ها الزاماً قفل نشده‌اند. ',
	'info_admin_plugin_actif_non_verrou_tous' => 'اين صفحه پلاگين‌هاي غيرفعال سايت را فهرست مي‌كند. اين پلاگين‌ها الزاماً قفل نشده هستند. ',
	'info_admin_plugin_actif_oui_verrou_non' => 'اين صفحه تمام پلگين‌هاي فعال و قفل نشده‌ي سايت را فهرست مي‌كند. ',
	'info_admin_plugin_actif_oui_verrou_tous' => 'اين صفحه تمام پلاگين‌هاي فعال سايت، قفل شده يا نشده را فهرست مي‌كند. ',
	'info_admin_plugin_verrou_non' => 'اين صفحه تمام پلاگين‌هاي قفل‌نشده‌ي سايت، فعال يا غيرفعال را فهرست مي‌كند. ',
	'info_admin_plugin_verrou_tous' => 'اين صفحه تمام پلاگين‌هاي سايت را فهرست مي‌كند.',
	'info_admin_plugin_verrouille' => 'اين صفحه پلاگين‌هاي فعال و قفل شده را فهرست مي‌كند (قرار گرفته در پوشه‌ي <code>@dir_plugins_dist@</code>).
اگر مايليد آن‌ها را غيرفعال كنيد لطفاً با وب مستر سايت تماس بگيريد، يا به  <a href="http://programmer.spip.org/repertoire_plugins_dist">à la documentation</a> گزارش كنيد. ', # MODIF
	'info_adresse_spipzone' => 'SPIP-Zone - Plugins',
	'info_ajouter_depot' => 'در جريان افزودن مخازن به پايگاه خود، امكان كسب اطلاعات و جستجو روي تمام پاكت‌هاي ذخيره شده به وسيله‌ي مخازن افزوده شده را خواهيد داشت. يك مخزن به وسيله‌ي يك پرونده‌ي ايكس.ام.ال نوشته شده كه شامل تمام اطلاعات در مورد مخزن و تمام پاكت‌هاي آن است. ‌ ',
	'info_aucun_depot' => 'هيچ مخزن',
	'info_aucun_depot_ajoute' => 'هيچ مخزني در دسترس نيست.<br /> از فرم زير براي افزودن مخزني  «SPIP-Zone - Plugins»كه يو.آر.ال آن از پيش داده شده استفاده كنيد يا مخزن ديگري را  انتخاب نماييد  ',
	'info_aucun_paquet' => 'هيچ پاكت',
	'info_aucun_plugin' => 'هيچ پلاگين',
	'info_boite_charger_plugin' => '<strong>اين صفحه انحصاراً در دسترس وب‌مستر‌هاي سايت قرار دارد.</strong><p>اين صفحه به شما اجازه خواهد داد تا پلاگين‌هاي قابل دسترس در مخازن ذخيره شده در پيكربندي خود را جستجو كنيد و آن‌ها به صورت فيزيكي روي سرور خود بارگذاري نماييد.  </p>


',
	'info_boite_depot_gerer' => '<strong>اين صفحه انحصاراً در دسترس وب مسترهاي سايت قرار دارد.</strong><p>اين صفحه اجازه‌ي افزودن و به هنگام سازي مخازن پلاگين‌ها را مي‌هد.</p>',
	'info_charger_plugin' => 'براي افزودن يك يا چند پلاگين، پيشاپيش يك جستجوي چند معياره روي پلاگين‌هاي كهشكان اسپيپ انجام دهيد. اين جستجو فقط شامل پلاگين‌هاي سازگار با نسخه‌ي اسپيپ نصب شده است و پلاگين‌هاي جخ فعال شده روي اين سايت را گزارش مي‌دهد. ',
	'info_compatibilite_dependance' => ' براي @compatibilite@:',
	'info_contributions_hebergees' => '@total_autres@ ساير كمك‌هاي پذيرش شده  ',
	'info_critere_phrase' => 'كليدواژه‌ها را باري جستجو در پيشوند،‌نام، شعار،‌ توصيف و پلاگين‌هاي ديگر تايپ كنيد
',
	'info_depots_disponibles' => '@total_depots@ مخزن',
	'info_fichier_depot' => 'يو.آر.ال پرونده‌ي توصيف مخزن را براي اضافه شدن تايپ كنيد. <br />براي افزودن مخزن "SPIP-Zone - Plugins" اين پيوند را كليك كنيد: 
',
	'info_nb_depots' => '@nb@ مخزن',
	'info_nb_paquets' => '@nb@پاكت ',
	'info_nb_plugins' => '@nb@ پلاگين',
	'info_paquets_disponibles' => '@total_paquets@ پاكت در دسترس',
	'info_plugin_attente_dependance' => 'وابسته‌هاي گم شده ',
	'info_plugin_incompatible' => 'نسخه‌ي ناسازگار ',
	'info_plugin_installe' => 'جخ نصب شده ',
	'info_plugin_obsolete' => 'نسخه‌ي كهنه',
	'info_plugins_disponibles' => '@total_plugins@ پلاگين در دسترس ',
	'info_plugins_heberges' => '@total_plugins@ پلاگين پذيرش شده',
	'info_tri_nom' => 'دسته بندي شده بر اساس الفبا',
	'info_tri_score' => 'دسته‌بندي شده بر اساس كاهش تناسب آن‌ها',
	'info_type_depot_git' => 'مخزن مديريت شده تحت جي.آي.تي',
	'info_type_depot_manuel' => 'مخزن مديريت شده با دست',
	'info_type_depot_svn' => 'مخزن مديريت شده تحت اس.وي.ان',
	'info_verrouille' => 'غيرفعال‌ سازي يا نصب زدايي اين پلاگين ممكن نيست',
	'installation_en_cours' => 'اقدام‌هاي درخواستي در دست اجراست',

	// L
	'label_1_autre_contribution' => 'كمك ديگر',
	'label_actualise_le' => 'فعال‌سازي شده',
	'label_archive' => 'يو.آر.ال آرشيو',
	'label_branches_spip' => 'سازگار',
	'label_categorie' => 'مقوله',
	'label_compatibilite_spip' => 'سازگاري',
	'label_critere_categorie' => 'مقوله‌ها',
	'label_critere_depot' => 'مخازن',
	'label_critere_doublon' => 'سازگاري',
	'label_critere_etat' => 'حالت‌ها',
	'label_critere_phrase' => 'جستجو در پلاگين‌ها',
	'label_destination' => 'مسير از پوشه‌ي «auto» كه پلاگين در آن ذخيره مي‌شود',
	'label_modifie_le' => 'اصلاح ...',
	'label_n_autres_contributions' => 'كمك‌هاي ديگر',
	'label_prefixe' => 'پيشوند',
	'label_selectionner_plugin' => 'انتخاب اين پلاگين',
	'label_tags' => 'برچسب‌ها: ',
	'label_type_depot' => 'نوع مخزن:',
	'label_type_depot_git' => 'مخزن تحت جي.آي.تي ',
	'label_type_depot_manuel' => 'مخزن دستي',
	'label_type_depot_svn' => 'مخزن تحت اس.وي.ان ',
	'label_url_archives' => 'يو.آر.ال بسته‌ي آرشيوها',
	'label_url_brouteur' => 'يو.آر.ال ريشه منابع ',
	'label_url_serveur' => 'يو.آر.ال سرور',
	'label_version' => 'نسخه',
	'label_xml_depot' => 'پرونده ايكس.ام.ال مخزن',
	'label_xml_plugin' => 'ايكس.ام.ال',
	'legende_installer_plugins' => 'نصب پلاگين‌ها',
	'legende_rechercher_plugins' => 'جستجوي پلاگين‌ها',

	// M
	'message_action_finale_get_fail' => 'پلاگين «@plugin@»(نسخه:@version@) نمي‌تواند به خوبي بارگذاري شود',
	'message_action_finale_get_ok' => 'پلاگين «@plugin@» (نسخه:@version@) به خوبي بارگذاري شده ',
	'message_action_finale_getlib_fail' => 'نصب آرشيو «@plugin@» نا موفق بوده ',
	'message_action_finale_getlib_ok' => 'آرشيو «@plugin@» نصب شده ',
	'message_action_finale_geton_fail' => 'بارگذاري يا فعال‌سازي پلاگين «@plugin@» (نسخه:@version@) به خوبي انجام نشده',
	'message_action_finale_geton_ok' => 'بارگذاري و فعال‌سازي پلاگين «@plugin@»(نسخه:@version@) به خوبي انجام شده ',
	'message_action_finale_install_fail' => 'نصب پلاگين «@plugin@» (نسخه: @version@) موفق نبوده ',
	'message_action_finale_install_ok' => 'نصب پلاگين «@plugin@» (نسخه: @version@) به خوبي انجام شده',
	'message_action_finale_kill_fail' => 'پرونده‌هاي پلاگين «@plugin@» (نسخه: @version@) به خوبي حذف نشده‌اند',
	'message_action_finale_kill_ok' => 'پرونده‌هاي پلاگين «@plugin@» (نسخه:  @version@) به خوبي حذف شده‌اند',
	'message_action_finale_off_fail' => 'غيرفعال‌سازي پلاگين «@plugin@» (نسخه: @version@) به خوبي انجام نشده',
	'message_action_finale_off_ok' => 'فعال سازي پلاگين «@plugin@»(نسخه: @version@) به خبوبي انچام شده ',
	'message_action_finale_on_fail' => 'فعال سازي پلاگين «@plugin@» (نسخه: @version@) به خوبي انجام نشده',
	'message_action_finale_on_ok' => 'فعال‌سازي پلاگين «@plugin@» (نسخه: @version@) به خوبي انجام شده ',
	'message_action_finale_stop_fail' => 'نصب زدايي پلاگين «@plugin@»(نسخه: @version@) به خوبي انجام نشده ',
	'message_action_finale_stop_ok' => 'نصب‌ زدايي پلاگين «@plugin@» (نسخه: @version@) به خوبي انجام شده',
	'message_action_finale_up_fail' => 'به هنگام سازي پلاگين «@plugin@» (از نسخه‌ي: @version@ تا @version_maj@) به خوبي انجام نشده',
	'message_action_finale_up_ok' => 'به هنگام سازي پلاگين «@plugin@» (از نسخه‌ي:@version@ تا @version_maj@) به خوبي انجام شده',
	'message_action_finale_upon_fail' => 'به هنگام سازي و فعال‌سازي پلاگين « @plugin@ »  (از نسخه‌‌ي: de la version : @version@ تا @version_maj@) به خوبي انجام نشده ',
	'message_action_finale_upon_ok' => 'به هنگام‌سازي و فعال‌سازي پلاگين « @plugin@ » (از نسخه: @version@ تا @version_maj@) به خوبي انجام شده',
	'message_action_get' => 'بارگذاري پلاگين «@plugin@» (نسخه: @version@)',
	'message_action_getlib' => 'بارگذاري آرشيو « <a href="@version@" class="spip_out">@plugin@</a> »',
	'message_action_geton' => 'بارگذاري و فعال‌ساز پلاگين «@plugin@» (نسخه: @version@)',
	'message_action_install' => 'پلاگين «@plugin@»(نسخه:@version@) نصب شد',
	'message_action_kill' => 'حذف پرونده‌هاي پلاگين «@plugin@» (نسخه: @version@)',
	'message_action_off' => 'غيرفعال‌سازي پلاگين  «@plugin@» (نسخه:@version@)',
	'message_action_on' => 'فعال‌سازي «@plugin@» (نسخه: @version@)',
	'message_action_stop' => 'نصب زدايي پلاگين «@plugin@» (نسخه: @version@)',
	'message_action_up' => 'به هنگام سازي پلاگين «@plugin@» (از نسخه @version@ تا @version_maj@)',
	'message_action_upon' => 'به هنگام سازي و فعال سازي پلاگين «@plugin@»(نسخه:@version@)',
	'message_dependance_plugin' => 'اين پلاگثن  @plugin@ بستگي دارد به @dependance@.',
	'message_dependance_plugin_version' => 'پلاگين  @plugin@ بستگي به  @dependance@ @version@دارد ',
	'message_erreur_aucun_plugin_selectionne' => 'هيچ پلاگيني انتخاب نشده.',
	'message_erreur_ecriture_lib' => '@plugin@ مستلزم آن است كه آرشيو  <a href="@lib_url@">@lib@</a> در پرونده‌ي  <var>lib/</var> در ريشه‌ي سايت شما قرار بگيرد. با اين حال، اين پوشه غيرقابل نگارش است. شما بايد آن را به صورت دستي نصب كنيد يا مجوز نوشتن در آن پوشه را بدهيد. 
', # MODIF
	'message_erreur_maj_inconnu' => 'به هنگام سازي پلاگين ناشناخته ممكن نسيت. ',
	'message_erreur_plugin_introuvable' => 'يافتن پلاگين @plugin@ براي@action@ ممكن نيست. ',
	'message_erreur_plugin_non_actif' => 'غيرفعال كردن پلاگيني كه فعال نيست ممكن نيست. ',
	'message_incompatibilite_spip' => '@plugin@ با نسخه‌ي اسپيپي كه مي‌خواهيد استفاده كنيد جور نيست.',
	'message_nok_aucun_depot_disponible' => 'هيچ پلاگيني در دسترس نيست! لطفاً براي افزودن فهرست‌هاي پلاگين‌ها به صفحه‌ي مديريت مخازن تشريف ببريد. 
',
	'message_nok_aucun_paquet_ajoute' => 'اين مخزن «@url@» هيچ پاكت جديدي كه با پايگاه الأن ثبت شده سازگار باشد ارايه نمي‌كند. در نتيجه اين مخزن افزوده نشده است. 
',
	'message_nok_aucun_plugin_selectionne' => 'پلاگيني براي نصب نيست. لطفاً پلاگين‌ها را براي نصب انتخاب كنيد.',
	'message_nok_champ_obligatoire' => 'اين ميدان اجباري است',
	'message_nok_depot_deja_ajoute' => 'نشاني «@url@» سازگار با مخزني كه الأن افزوده شده',
	'message_nok_maj_introuvable' => 'به هنگام سازي پلاگين @plugin@(@id@).يافت نمي‌شود',
	'message_nok_plugin_inexistant' => 'پلاگين درخواست شده موجود نيست (@plugin@).',
	'message_nok_sql_insert_depot' => 'خطاي اس‌.كيو.ال وقتي مخزن @objet@افزوده مي‌شود
',
	'message_nok_url_depot_incorrecte' => ' نشاني«@url@» درست نيست',
	'message_nok_xml_non_conforme' => 'پرونده ايكس.ام.ال «@fichier@»در توصيف مخزن تأييد نمي‌شود. ',
	'message_ok_aucun_plugin_trouve' => 'هيچ پلاگيني با معيار‌هاي منتخب جور نيست.',
	'message_ok_depot_ajoute' => 'مخزن «@url@» افزوده شده.',
	'message_ok_plugins_trouves' => '@nb_plugins@.در زير پلاگين‌هايي را كه مي‌خواهيد بارگذاري كرده و در سرور خود فعال كنيد، انتخاب نماييد. پلاگين با معيارهاي منتخب(@tri@) جور است
',
	'message_telechargement_archive_effectue' => 'آرشيو به درستي به @dir@ استخراج شد.',

	// N
	'nettoyer_actions' => 'حذف اين اقدام‌ها! اين كار فهرست اقدام‌هاي مانده براي اجرا را پاك مي‌كند. ',

	// O
	'onglet_depots' => 'مديريت مخازن',
	'option_categorie_toute' => 'تمام مقوله‌ها',
	'option_depot_tout' => 'تمام مخازن',
	'option_doublon_non' => 'آخرين نسخه',
	'option_doublon_oui' => 'تمام نسخه‌هاي در دسترس',
	'option_etat_tout' => 'تمام حالت‌ها',

	// P
	'placeholder_phrase' => 'پيشوند،‌اسم، شعار، توصيف يا ديگر',
	'plugin_info_actif' => 'پلاگين فعال ',
	'plugin_info_up' => ' يك به‌ هنگام سازي شده‌ از اين پلاگين در دسترس است (نسخه@version@‌ )',
	'plugin_info_verrouille' => 'پلاگين قفل شده ',
	'plugins_inactifs_liste' => 'غيرفعال‌ها',
	'plugins_non_verrouilles_liste' => 'قفل نشده‌ها',
	'plugins_verrouilles_liste' => 'قفل‌شده‌ها',

	// R
	'resume_table_depots' => 'فهرست مخازن افزوده شده',
	'resume_table_paquets' => 'فهرست پاكت‌ها',
	'resume_table_plugins' => 'فهرست پلاگين‌ها @categorie@',

	// T
	'telecharger_archive_plugin_explication' => 'مي‌توانيد آرشيوي را كه در پوشه‌ي شما بارگذاشته خواهد شد، با نوشتن يو.آر.ال اين پوشه در مدخل ميدان، بارگذاري كنيد.  
',
	'titre_depot' => 'مخزن',
	'titre_depots' => 'مخزن‌ها',
	'titre_form_ajouter_depot' => 'افزودن يك سپرده ',
	'titre_form_charger_plugin' => 'جستجو و افزودن پلاگين‌ها',
	'titre_form_charger_plugin_archive' => 'بارگذاري يك پلاگين از پوشه‌اش',
	'titre_form_configurer_svp' => 'پيكربندي سرور پلاگين‌ها',
	'titre_liste_autres_contributions' => 'اسكلت‌ها، كتابخانه‌ها، سري آيكون‌ها', # MODIF
	'titre_liste_autres_depots' => 'سپرده‌هاي ديگر',
	'titre_liste_depots' => 'فهرست مخازن در دسترس',
	'titre_liste_paquets_plugin' => 'فهرست پاكت‌هاي پلاگين',
	'titre_liste_plugins' => 'فهرست پلاگين‌ها',
	'titre_logo_depot' => 'لوگوي سپرده',
	'titre_logo_plugin' => 'لوگوي پلاگين',
	'titre_nouveau_depot' => 'سپرده‌ي جديد',
	'titre_page_configurer' => 'سرور پلاگين‌ها',
	'titre_paquet' => 'پاكت ',
	'titre_paquets' => 'پاكت‌ها',
	'titre_plugin' => 'ويرايش مستقيم',
	'titre_plugins' => 'پلاگين‌ها',
	'tout_cocher' => 'علامت زدن همه',
	'tout_cocher_up' => 'علامت زدن به‌ هنگام‌سازي‌ها',
	'tout_decocher' => 'رها كردن همه'
);

?>
